@@ -66,7 +66,7 @@ see.beta.tck<-function ()
 
 see.betacdf.tck<-function (){ 
 
-  old.par <- par(no.readonly = TRUE)
+#  old.par <- par(no.readonly = TRUE)
     if (!exists("slider.env"))
     slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     alpha <- 1
@@ -130,6 +130,6 @@ see.betacdf.tck<-function (){
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
     
-    on.exit(par(old.par))
+ #   on.exit(par(old.par))
   }  
                             
\ No newline at end of file
