@@ -64,7 +64,7 @@ see.logis.tck<-function ()
 
 
 see.logiscdf.tck<-function (){ 
-  old.par <- par(no.readonly = TRUE)
+#  old.par <- par(no.readonly = TRUE)
     if (!exists("slider.env")) 
         slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     theta <- 1
@@ -126,6 +126,6 @@ see.logiscdf.tck<-function (){
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
-    on.exit(par(old.par))
+ #   on.exit(par(old.par))
   }  
                             
\ No newline at end of file
